@@ -1099,8 +1099,13 @@ makeUpdate <- function(modelInit,
     
   }else if(!willBeGam & !isGlm & hasBars & !isGam){
     
-    mod <- update(modelInit,
-                  formula = setup$random)    
+    form <- setup$random
+    if(!is.null(setup$gamPart))
+      form <- paste0(paste(format(setup$gamPart), 
+                           collapse=""), 
+                     " + ", setup$random)
+    
+    mod <- update(modelInit, formula = form)    
     
   }else if(!willBeGam & !hasBars & !isGam){
     
@@ -1120,10 +1125,18 @@ makeUpdate <- function(modelInit,
                  family(modelInit$mer)$family,
                  family(modelInit)$family)
     
+    if(length(modelInit$gam$smooth)==0)
+    {
+      # actually a Glm
+      this_data <- data
+    }else{
+      this_data <- attr(data, "orgname")
+    }
+    
     mod <- eval(parse(text=paste0("glm(",paste(format(setup$gamPart), 
                                                collapse=""),
                                   ", family = ", fm, ", data = ",
-                                  attr(data, "orgname"),")")))   
+                                  "this_data",")")))   
     
     
   }else{ # willBeGam
